==> catalystcentersdk-2.3.7.9.3-py3-none-any.whl: catalystcentersdk/_metadata.py <==
# -*- coding: utf-8 -*-
"""Package metadata.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


__title__ = 'catalystcentersdk'
__description__ = 'Community-developed Python SDK for the CatalystCenter APIs'
__url__ = 'https://github.com/cisco-en-programmability/catalystcentersdk'
__download_url__ = 'https://pypi.python.org/pypi/catalystcentersdk'
__author__ = 'Jose Bogarín'
__author_email__ = 'jbogarin@altus.cr'
__copyright__ = "Copyright (c) 2024 Cisco Systems, Inc."
__license__ = "MIT"

==> catalystcentersdk-3.1.3.0.0-py3-none-any.whl: catalystcentersdk/_metadata.py <==
# -*- coding: utf-8 -*-
"""Package metadata.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


__title__ = "catalystcentersdk"
__description__ = "Community-developed Python SDK for the CatalystCenter APIs"
__url__ = "https://github.com/cisco-en-programmability/catalystcentersdk"
__download_url__ = "https://pypi.python.org/pypi/catalystcentersdk"
__author__ = "Jose Bogarín"
__author_email__ = "jbogarin@cloverhound.com"
__copyright__ = "Copyright (c) 2024 Cisco Systems, Inc."
__license__ = "MIT"
